#!/usr/bin/env python

'''
Wrapper for the official Ansible Playbook application
=====================================================
'''

import os
import argparse
from subprocess import call

def callAnsible(playbook, inventory, args):
    cmd = ['ansible-playbook', playbook + '.yml', '-i', inventory]
    for arg in args:
        cmd.append(arg)
    call(cmd, cwd=path)

parser = argparse.ArgumentParser(description='Ansible Playbook wrapper by Paragon')
parser.add_argument('playbook',
                    help='Playbook to execute')
parser.add_argument('--local', action='store_true', default=False,
                    help='Set to true to work with the localhost only')
parser.add_argument('--custom', action='store_true', default=False,
                    help='Set to true to only execute playbook in the inventory directory')

args, extras = parser.parse_known_args()

path = os.path.dirname(os.path.realpath(__file__)) + '/'
pathSecrets = os.path.realpath(os.environ['HOME']) + '/.ansible/secrets'
pathCustom = path

# Start building command
cmd = []

# Determine inventory file
if args.local:
    inventory = path + 'local.inventory'
    pathCustom = False
elif os.path.exists(path + 'inventory/inventory'):
    inventory = path + 'inventory/inventory'
    pathCustom = path + 'inventory/'
else:
    inventory = path + 'inventory/' + os.environ['ANSIBLE_COMPANY'] + '/inventory'
    pathCustom = path + 'inventory/' + os.environ['ANSIBLE_COMPANY'] + '/'
if not os.path.exists(inventory):
    raise SystemError('Inventory %s not found' % inventory)

# Check for the vault
if os.path.exists(pathSecrets):
    cmd.append('-e')
    cmd.append('@' + pathSecrets)
else:
    cmd.append('--ask-sudo-pass')

# Append more CLI options
for extra in extras:
    cmd.append(extra)

# Run the main playbook if not in custom mode
if not args.custom:
    callAnsible(args.playbook, inventory, cmd)

# Optionally also run the custom playbook
if pathCustom and os.path.exists(pathCustom + args.playbook + '.yml'):
    callAnsible(pathCustom + args.playbook, inventory, cmd)
