#!/usr/bin/env python

'''
Wrapper for the official Ansible application
============================================
'''

import os
import argparse
from subprocess import call

parser = argparse.ArgumentParser(description='Ansible wrapper by Paragon')
parser.add_argument('host',
                    help='Host name or pattern')

args, extras = parser.parse_known_args()

path = os.path.dirname(os.path.realpath(__file__)) + os.path.sep
pathSecrets = os.path.realpath(os.environ['HOME']) + '/.ansible/secrets'

# Start building command
cmd = ['ansible', args.host]

# Determine inventory file
if os.path.exists(path + 'inventory/inventory'):
    inventory = path + 'inventory/inventory'
else:
    inventory = path + 'inventory/' + os.environ['ANSIBLE_COMPANY'] + '/inventory'
if not os.path.exists(inventory):
    raise SystemError('Inventory %s not found' % inventory)
cmd.append('-i')
cmd.append(inventory)

# Check for the vault
if os.path.exists(pathSecrets):
    cmd.append('-e')
    cmd.append('@' + pathSecrets)

# Append more CLI options
for extra in extras:
    cmd.append(extra)

call(cmd, cwd=path)
