#!/usr/bin/env python

'''
Script to start the inithost playbook
=====================================
'''

import os
import argparse
from subprocess import call

parser = argparse.ArgumentParser(description='Launch the Ansible playbook inithost')
parser.add_argument('host',
                    help='Name of the host to be created')

cloudGroup = parser.add_argument_group('Cloud', 'When installing through a cloud proivider, use these options')
cloudGroup.add_argument('--cloud', action='store', choices=['ec2', 'jiffybox'],
                    help='The cloud provider')
cloudGroup.add_argument('--groups', action='store',
                    help='The inventory groups for the host as comma separated list')

nonCloudGroup = parser.add_argument_group('Non-Cloud', 'When installing directly, use these options')
nonCloudGroup.add_argument('--ip', action='store',
                   help='The ip address of the host, only required if not installed in the cloud')

parser.add_argument('--user', action='store', default=os.environ['USER'],
                    help='The username of the first created admin user')
parser.add_argument('--root', action='store', default='root',
                    help='The username to use initially')
parser.add_argument('--key', action='store',
                    help='File name with the private key to be used initially')

args, extras = parser.parse_known_args()

path = os.path.dirname(os.path.realpath(__file__)) + os.path.sep

extraVars = ['host=' + args.host, 'distribute_keys=true', 'inituser=' + args.root, 'firstuser=' + args.user]
if args.cloud:
    extraVars.append('cloud=' + args.cloud)
if args.groups:
    extraVars.append('initgroups=' + args.groups)
if args.ip:
    extraVars.append('inithostip=' + args.ip)

cmd = [path + 'ansible-playbook.sh', 'inithost', '--extra-vars=' + ' '.join(extraVars)]

if args.key:
    cmd.append('--private-key=' + args.key)
else:
    cmd.append('--ask-pass')

for extra in extras:
    cmd.append(extra)

call(cmd)
